from extras.plugins import PluginConfig


class NetboxAutoNamesConfig(PluginConfig):
    name = 'netbox_autonames'
    verbose_name = 'NetBoxAutoNames'
    version = '0.1'
    description = 'Auto-generate names for devices in NetBox based on their role.'
    base_url = ''
    required_settings = ['DEVICE_NAME_MAP']
    min_version = '2.10.0'

    def ready(self):
        import netbox_autonames.signals


config = NetboxAutoNamesConfig



from django.db.models.signals import pre_save
from django.dispatch import receiver
from dcim.models import Device
from django.conf import settings
import re

@receiver(pre_save, sender=Device)
def auto_generate_device_name(sender, instance, **kwargs):
    try:
        if not instance.name:
            role = instance.role.slug
            device_name_map = settings.PLUGINS_CONFIG['netbox_autonames'].get('DEVICE_NAME_MAP', {})
            prefix = device_name_map.get(role)
            if prefix:
                pattern = re.compile(f'^{prefix}(\d+)$')
                existing_devices = Device.objects.filter(role__slug=role)
                max_num = 0
                for device in existing_devices:
                    if device.name is None:
                        continue
                    match = pattern.match(device.name)
                    if match:
                        num = int(match.group(1))
                        if num > max_num:
                            max_num = num
                next_num = max_num + 1
                instance.name = f"{prefix}{next_num:04d}"
    except Exception as e:
        pass



from setuptools import find_packages, setup

setup(
    name='netbox_autonames',
    version='0.2',
    description='Auto-generate names for devices in NetBox based on their role.',
    url='https://github.com/jaannnis/netbox_autonames',
    author='jannis',
    license='AGPLv3',
    install_requires=[],
    packages=find_packages(),
    include_package_data=True,
    zip_safe=False,
)
